function [output] = mol_weight(A1,a1,A2,a2,A3,a3,A4,a4,A5,a5);
% Usage: [output] = mol_weight('Fe',1,'F',2);
%
% This function calculates the molecular weight of a compound using data
% obtained from webelements.com for atomic weights.  The atomic weights are
% rounded to 3 decimal places where appropriate, although for several 
% elements the apparent accuracy is not good enough to support this level 
% of precision.  The atomic weights are given in the accompanying text file
% atomic_weight.txt.
%
% Currently, the function will only accept up to 5 different elements as
% part of a compound.  The element name, in quotes, should be followed by
% the relative quantity (this may be fractional).  For a single element, it
% is not necessary to include the quantity - this is assumed to be 1.
%
% Note that not all of the atomic weights have been checked; transcription
% errors may be present.

% Elizabeth Blackburn, 11/08/2006.

% -------------------------------------------------------------------------
% Check the inputs
% ----------------
if nargin < 2
    a1 = 1; no_elements = 1;
else
    no_elements = int8(nargin) / 2;
    if isinteger(no_elements) ~= 1
        error('Input error - elements and quantities do not match')
    end
end

if nargin > 11
    error('Input error - too many elements')
end

% Call the data table
% -------------------
[label,weight] = textread('atomic_weight.txt','%s %f',-1);

total_mass = 0;

% Calculate the 'weight' for each element and add together
% ------------------------------------------------------
for i = 1:no_elements
    eval(['element = A',num2str(i),';'])
    eval(['quantity = a',num2str(i),';'])
    locate_element = strcmp(label,element);
    locator = find(locate_element == 1);
    if (isempty(locator) == 1)
        error('Input error - one of the elements does not exist')
    end
    element_mass = weight(locator);
    relative_mass = element_mass*quantity;
    total_mass = total_mass + relative_mass;
end

% Output
% ------
output = total_mass;
